#!/usr/bin/env ruby
# Copyright (C) [2009-2010] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

#This script is to reconfigure LUM after a server ID swap

require 'rubygems'
require 'mig'
include Migration

def generateServCert 
  # First see if the server is available.... Do ping and get the result..
  print_message(INFO, "Contacting the server #{@opt['s']}")
  res = `ping -q -c 3 #{@opt['s']}`
  if $? != 0
    print_message(ERROR, "Could not connect to #{@opt['s']} server")
    exit 1
  else
    print_message(DEBUG, "ping is successful")
  end 
  if @opt['file']
    outFile = @opt['file']
  else
    outFile = "/tmp/cert"
  end
  outFile = outFile+".der"
  print_message(INFO, "Executing openssl command 'echo |openssl s_client -connect #{@opt['s']}:#{@opt['ldap-port']} > #{outFile} 2>&1'")
  res = `echo | openssl s_client -connect #{@opt['s']}:#{@opt['ldap-port']} > #{outFile} 2>&1`
  if $? != 0
    print_message(ERROR, "Failed to execute command 'echo | openssl s_client -connect #{@opt['s']}:#{@opt['ldap-port']} > #{outFile} 2>&1'")
    if File.exist? outFile
      print_message(ERROR, "#{File.readlines(outFile)}") if File.exist?(outFile)
      File.delete(outFile)
      exit 1
    end
  else
    if File.exist?(outFile)
      print_message(INFO, "File #{outFile} created")
      `grep "BEGIN CERTIFICATE" #{outFile}`
      if $? != 0
        print_message(ERROR, "File #{outFile} is not a valid certificate file. No 'BEGIN CERTIFICATE' string")
        File.delete(outFile)
        exit 1
      end
      `grep "END CERTIFICATE" #{outFile}`
      if $? != 0
        print_message(ERROR, "File #{outFile} is not a valid certificate file. No 'END CERTIFICATE' string")
        File.delete(outFile)
        exit 1
      end
      res = `sed -i -ne '/-BEGIN CERTIFICATE-/,/-END CERTIFICATE-/p' #{outFile}`
      if $? != 0
        print_message(ERROR, "Failed to execute command 'sed command 'sed -i -ne '/-BEGIN CERTIFICATE-/,/-END CERTIFICATE-/p' /tmp/f1'")
        File.delete(outFile)
        exit 1
      else
        print_message(INFO, "Successfully created certificate file #{outFile}")
      end
    end
  end
end
#main
def main
  $argdef = [
    ['s','server-ip', "Specify the hostname or IP address of the preferred LDAP eDirectory server to be contacted",ParseArgText,true],
    [nil, 'ldap-port', "Specify port where LDAP server is listening", ParseArgText, false],
    [nil, 'file', "Specify the full path of the file to store the certificate. File will be created with extension .der", ParseArgText, false]
  ]

  initLog(false, "getServerCert")
  (@opt, extraargs) = parseargs(ARGV, $argdef)
  if not @opt['ldap-port']
    @opt['ldap-port'] = 636
  end
   generateServCert()
   exit 0
end

begin
  main

rescue SystemCallError => failed  
  print_message(FATAL, "SystemCallError, #{failed.message}")
  exit failed.errno
rescue MigrationException => e 
  print_message(FATAL, "MigrationException, " + e.to_s)
  exit e.code 
rescue MigSyntaxError => e
  print_message(FATAL, "MigSyntaxError, " + e.to_s)
  printUsage($argdef)
  exit e.code
rescue Interrupt
  print_message(DEBUG, "Interrupted by user")
  writeToSessionFile(@jobDone, @cnt) if @opt['c'] and @init == false
  exit 0
rescue 
  print_message(FATAL, "Caught exception: #{$!.message}\n Backtrace:\n #{$!.backtrace.join("\n")}")
  exit 1
end
