#!/usr/bin/env ruby
# Copyright (C) [2010-2011] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

#This script is to reconfigure LUM after a server ID swap

require 'rubygems'
require 'mig'
include Migration

# Fix for BugZilla#698726
# explicitly call YaST with a dummy UI so that ncurses doesn't eat the terminal
def yast_cli(modul, *args)
  args_string = ""
  unless args.empty?
    parenthesized_args = args.map {|a| "'(#{a})'"}
    args_string = "-S " + parenthesized_args.join(" ")
  end
  cmdline = "LC_ALL=en_US /usr/lib/YaST2/bin/y2base #{modul} #{args_string} UI 2>&1"
  #Lets print out the command, so that user is aware of the sequence
  puts "Executing command: #{cmdline}"
  cmdline
end

#main
def main
  $argdef = [
    [nil, 'old-ip', "Specifies the old IP address", ParseArgText, true],
    [nil, 'ip', "Specifies the new IP address", ParseArgText, true],
    [nil, 'netmask', "Specifies the new mask", ParseArgText]
#    [nil, '--password', "The administrator's password", ParseArgText]
  ]

  initLog(false, "yast-ipchange.rb")
  (@opt, extraargs) = parseargs(ARGV, $argdef)
  
  out = `#{yast_cli("lan", "list")} | grep #{@opt['old-ip']}`
  if out.nil? or out.empty?
    print_message(FATAL,"Old IP specified #{@opt['old-ip']} not bound to the server.")
    exit 1
  end
  id = out.split[0]
  if @opt['netmask']
    mask = "#{@opt['netmask']}"
  else
    #get the netmask from ip address
    line = `LC_ALL=en_US /sbin/ip address | grep #{@opt['old-ip']}`
    line.strip! 
    subnetMask = line[line.index("/")+1, 2]
    subnetArray = { "1" => "128.0.0.0", "2" => "192.0.0.0", "3" => "224.0.0.0", "4" => "240.0.0.0", "5" => "248.0.0.0", "6" => "252.0.0.0", "7" => "254.0.0.0", "8" => "255.0.0.0", "9" => "255.128.0.0", "10" => "255.192.0.0", "11" => "255.224.0.0",
    "12" => "255.240.0.0", "13" => "255.248.0.0", "14" => "255.252.0.0", "15" => "255.254.0.0", "16" =>	"255.255.0.0",	"17" =>	"255.255.128.0", "18" => "255.255.192.0", "19" => "255.255.224.0", "20" => "255.255.240.0", "21" => "255.255.248.0",	
    "22" => "255.255.252.0", "23" => "255.255.254.0", "24" => "255.255.255.0",	"25" =>	"255.255.255.128", "26" => "255.255.255.192", "27" => "255.255.255.224", "28" => "255.255.255.240", "29" => "255.255.255.248",	
    "30" => "255.255.255.252", "31" => "255.255.255.254", "32" => "255.255.255.255" }

    mask= subnetArray[subnetMask]
  end
  
   cmd = yast_cli("lan", "edit", "ip=#{@opt['ip']}", "netmask=#{mask}", "bootproto=static", "id=#{id}")
#  puts "cmd = #{cmd}"
   out = `#{cmd}`
#  if not out.include?("Changing Configuration for")
  if $?.to_i != 0
    print_message(FATAL,"Failed to change ip address. Cmd: #{cmd} output: #{out}")
    exit 1
  end
  exit 0
end

begin
  main
rescue SystemCallError => failed  
  print_message(FATAL, "SystemCallError, #{failed.message}")
  exit failed.errno
rescue MigrationException => e 
  print_message(FATAL, "MigrationException, " + e.to_s)
  exit e.code 
rescue MigSyntaxError => e
  print_message(FATAL, "MigSyntaxError, " + e.to_s)
  printUsage($argdef)
  exit e.code
rescue Interrupt
  print_message(DEBUG, "Interrupted by user")
  writeToSessionFile(@jobDone, @cnt) if @opt['c'] and @init == false
  exit 0
rescue 
  print_message(FATAL, "Caught exception: #{$!.message}\n Backtrace:\n #{$!.backtrace.join("\n")}")
  exit 1
end
