#!/usr/bin/env ruby
# Copyright (C) [2013-2014] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

#This script is to get the stale objects and to delete the stale objects from eDirectory.
#This is a new script introduced in miggui to provide the fix for the bug #741618

require 'rubygems'
require 'etc'
require 'expect'
require 'logger'
require 'open3'
require 'mig'
include Migration

#Some of the edir attribute values span over multiple lines. We need to capture the value as a single entity. So piping the output of ldapsearch to sed.
#Fix for Bug #890560
def getStaleObjects host, userDN, shortHost, passwd
    cmd = "/usr/bin/ldapsearch -LLL -s sub -H ldaps://#{host} -x -D \"#{userDN}\" \"(&(CN=*#{shortHost}*)(|(objectClass=SAS:Service)(objectClass=NDSPKI:Key Material)(objectClass=Volume)(objectClass=ndsVolume)(&(CN=OESCommonProxy*)(objectClass=User))(objectClass=nssfsPool)))\" -W dn | sed ' /^ / {; H; d; }; /^ /! {; x; s/\\n //; };'"
    print_message(INFO, "Executing command to get the stale objects = #{cmd}")
    options = {}
    options[:password] = passwd
    res = executeLdapCmd(cmd, options)
    print_message(INFO, "The stale objects are: ") 
    if res != "" and res != nil
      res.each do |staleObj|
        print_message(INFO, "#{staleObj}")
      end
    end 
end

def deleteStaleObjects host, userDN, objectsFile, passwd
    cmd = "/usr/bin/ldapdelete -H ldaps://#{host} -x -D \"#{userDN}\" -f \"#{objectsFile}\" -W"
    print_message(INFO, "Executing command to delete the stale objects = #{cmd}")
    options = {}
    options[:password] = passwd
    result = executeLdapCmd(cmd, options)
end

def main
 $argdef = [
    ['a', 'adminFDN', "The administrator's FDN specified in LDAP format", ParseArgText, true],
    ['p', 'pwd', "The administrator's password", ParseArgText, false],
    ['H', 'host', "The server's host name", ParseArgText, true],
    ['s', 'shortHost', "The server's short host name", ParseArgText, false],
    ['g', 'getObjects', "To get the stale objects from eDirectory", ParseArgBool, false],
    ['', 'deleteObjects', "To delete the stale objects from eDirectory", ParseArgBool, false],
    ['f', 'staleObjectsFile', "The file contianing the stale objects to be deleted", ParseArgText, false],
    [nil, 'debug', "Enalbe dubug", ParseArgBool, false],
    ParseArgHelp,
    ParseArgUsage
  ]
 volguidCommand = "#{$0}"  # name of the script.
 debugOpt = false
 getObjects = false
 deleteObjects = false

 $*.each do |arg|
   if arg.strip == "-g" or arg.strip == "--getObjects"
      getObjects = true
   end
   if arg.strip == "--deleteObjects"
      deleteObjects = true
   end
   volguidCommand += " #{arg}" # Form the actual command executed.
 end

  initLog(debugOpt, "cleanedirobjects")
  print_message(DEBUG, "migcleanup command started at #{`date +%d-%m-%y\\ %H:%M:%S`}")
  print_message(INFO, "migcleanup command executed as: #{volguidCommand}") 
  
 (@opt, extraargs) = parseargs(ARGV, $argdef)

  # Check if env variable is set. If not check for option 'p' in the arguments passed. If not present prompt the user for password.
 if ENV['REPAIR_ADMIN_PWD'] == nil or ENV['REPAIR_ADMIN_PWD'] == ""
  if not @opt['p']
    flag = true
    $stderr.print "Enter #{@opt['a']} password: "
       if $stdin.isatty
       `stty -echo`
       end
       @opt['p'] = $stdin.gets.chomp
       puts "\n" # to show prompt in next line
       if $stdin.isatty
       `stty echo`
       end
       # Alert the user if he enters empty password
       if @opt['p'].empty? or @opt['p'] == nil
         print_message(FATAL, "Invalid Arguments: Password is empty")
         exit 1
       end
  end
 end

  # Validate arguments
  if @opt['p']
        ENV['REPAIR_ADMIN_PWD'] = @opt['p']
  end
 
 if getObjects == true
   getStaleObjects @opt['H'], @opt['a'], @opt['s'], ENV['REPAIR_ADMIN_PWD']
 end
 if deleteObjects == true
   deleteStaleObjects @opt['H'], @opt['a'], @opt['f'], ENV['REPAIR_ADMIN_PWD']
 end
end # main ends here

begin
main
rescue SystemCallError => failed
  print_message(FATAL, "SystemCallError, #{failed.message}")
  exit failed.errno
rescue MigrationException => e
  print_message(FATAL, "MigrationException, " + e.to_s)
  exit e.code
rescue MigSyntaxError => e
  print_message(FATAL, "MigSyntaxError, " + e.to_s)
  printUsage($argdef)
  exit e.code
rescue Interrupt
  print_message(DEBUG, "Interrupted by user")
  writeToSessionFile(@jobDone, @cnt) if @opt['c'] and @init == false
  exit 0
rescue LdapAuthError => e
  print_message(FATAL, "Ldap Authentication Error, " + e.to_s)
  exit e.code
rescue
  print_message(FATAL, "Caught exception: #{$!.message}\n Backtrace:\n #{$!.backtrace.join("\n")}")
  exit 1
ensure
  puts "\n" #shows the prompt in next line if user presses Ctrl+c
  if $stdin.isatty
   `stty echo`
  end
end


