#!/usr/bin/env ruby
# Copyright (C) [2007-2008] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

#This script is to reconfigure LUM after a server ID swap

require 'rubygems'
require 'mig'
include Migration

def getAndFixUsers grpFdn
  host = getldapString
  users = `ldapsearch -LLL -x -H #{host} -b "#{grpFdn}" member`
  if $? != 0
    print_message(FATAL, "Unable to get users for group #{grpFdn}. ldapsearch failed. Returned #{users}")
    exit 1
  end
  if not users.nil? and not users.empty? and users.include?("member")
    users.each_line { | line |
      line.strip!
      if line.include?("member") and (line.include?("cn=admin,") or
                                      line.include?("cn=wwwrun,") or
                                      line.include?("cn=novlxsrvd,") or
                                      line.include?("cn=novlxregd,"))
        usrFdn = line.split(":", 2)[1]
        cmd = "namusermod -a \"#{@opt['a']}\" -g \"#{grpFdn}\" \"#{usrFdn}\""
        system(cmd)
      end
    }
  end
end

def modGrpsAndUsers searchBase, serverName, passwd
  host = getldapString
  if not searchBase.nil?
  #Some of the edir attribute values span over multiple lines. We need to capture the value as a single entity.
  #Fix for BugZilla|#767587
sleep(10)
  #Print the ldapsearch command mainly will be used for debugging purpose
  cmd = "ldapsearch -LLL -s sub -x -H #{host} -b \"#{searchBase}\" -D \"#{@opt['a']}\" -W \"(&(objectclass=uamPosixWorkstation)(cn=UNIX Workstation - #{serverName}))\" groupMembership | sed ' /^ / {; H; d; }; /^ /! {; x; s/\\n //; };'"
  print_message(INFO,"Executing command: #{cmd}")

  #When the script is called from miggui, opt['p'] is empty. Use the passwd that is being passed. Fix for BugZilla#824595 
  unixWrkStn = `ldapsearch -LLL -s sub -x -H #{host} -b "#{searchBase}" -D "#{@opt['a']}" -w "#{passwd}" "(&(objectclass=uamPosixWorkstation)(cn=UNIX Workstation - #{serverName}))" groupMembership | sed ' /^ / {; H; d; }; /^ /! {; x; s/\\n //; };'`     
    if $? != 0 or unixWrkStn.nil? or unixWrkStn.empty? or not unixWrkStn.include?("dn:")
      unixWrkStn = `ldapsearch -LLL -s sub -x -H #{host} -D "#{@opt['a']}" -w "#{passwd}" "(&(objectclass=uamPosixWorkstation)(cn=UNIX Workstation - #{serverName}))" groupMembership | sed ' /^ / {; H; d; }; /^ /! {; x; s/\\n //; };'`
    end
  else
    unixWrkStn = `ldapsearch -LLL -s sub -x -H #{host} -D "#{@opt['a']}" -w "#{passwd}" "(&(objectclass=uamPosixWorkstation)(cn=UNIX Workstation - #{serverName}))" groupMembership | sed ' /^ / {; H; d; }; /^ /! {; x; s/\\n //; };'`
  end
  if $? != 0 or unixWrkStn.nil? or unixWrkStn.empty?
    print_message(FATAL, "Unable to get UNIX Workstation object. ldapsearch failed. Returned #{unixWrkStn}")
    exit 1
  end
  print_message(INFO, "unixWrkStn: #{unixWrkStn}")
  if unixWrkStn.include?("groupMembership")
    unixWrkStn.each_line { | line | 
      if line.include?("groupMembership:") and (line.include?("cn=admingroup,") or
                                                line.include?("cn=novlxtier,") or
                                                line.include?("cn=www,"))
        line.strip!
        grpFdn = line.split(":", 2)[1]       #cn=www,ou=wgp,o=novell
        
        #modify the group
        cmd = "namgroupmod -a \"#{@opt['a']}\" -W \"#{@opt['H']}\" \"#{grpFdn}\""
        print_message(INFO, "LUM enabling group #{grpFdn} with command #{cmd}\n")

        # Checking for return value and showing to the user
        result = `#{cmd}`
        if $? != 0
           print_message(ERROR, "Failed to execute the command #{cmd} with result #{result}")
        end

        # No need to LUM enable all users in each group, as they are already
        # LUM enabled. All we need to do is LUM enable groups. Fix for #709477
        #got the group fdn, get the users and process them
        #getAndFixUsers(grpFdn)
      end
    }
  else
    print_message(WARN, "UNIX Workstation object has no groups. ldapsearch returned #{unixWrkStn}")
    exit 1
  end
end

def getldapString
  if @opt['use-unsecure-ldap'] == nil
    part_string = "ldaps"
  else
    part_string = "ldap"
  end
  if @opt['ldap-port'] == nil
    host = "#{part_string}:\/\/#{@opt['S']}"
  else
    host = "#{part_string}:\/\/#{@opt['S']}:#{@opt['ldap-port']}"
  end
  return host
end

#main
def main
  $argdef = [
    ['H', 'hostname', "Specify the hostname", ParseArgText,true],
    ['a', 'adminFDN', "Specify in LDAP format, the administrator's name", ParseArgText, true],
    ['p', 'pwd', "Specify the administrator's password", ParseArgText, false],
    ['S', nil, "Specify the IP address of the preferred LDAP eDirectory server to be contacted",ParseArgText, true],
    [nil, 'use-unsecure-ldap', "Specify to use unsecure LDAP for all LDAP commands", ParseArgBool, false],
    [nil, 'ldap-port', "Specify the port where LDAP server is listening", ParseArgText, false]
  ]

  initLog(false, "nam-fix.rb")
  (@opt, extraargs) = parseargs(ARGV, $argdef)

  if @opt['p']
    ENV['LUM_PWD'] = @opt['p']
  end
  if ENV['LUM_PWD'] == nil
    print_message(FATAL, "Invalid Arguments: Password is not specified")
    exit 1
  end

  # we need to use this password for ldap commands. Fix for BugZilla#824595
  passwd = ENV['LUM_PWD']

  # Fix for BugZilla#698745, to search LUM base using workstation-context. 
  searchBaseStr = `/usr/bin/namconfig get workstation-context`
  if searchBaseStr == nil or searchBaseStr.empty?
      print_message(FATAL, "Failed to get LUM search base using namconfig get workstation-context")
      exit 1
  end
  searchBase =  searchBaseStr[searchBaseStr.index("=")+1, searchBaseStr.length]
  if searchBase.nil? or searchBase.length == 0
    print_message(WARN, "Unable to get workstation-context")
    modGrpsAndUsers(nil, @opt['H'], passwd)
  else
    searchBase.strip!
    modGrpsAndUsers(searchBase, @opt['H'], passwd)
  end
  exit 0
end

begin
  main
rescue SystemCallError => failed  
  print_message(FATAL, "SystemCallError, #{failed.message}")
  exit failed.errno
rescue MigrationException => e 
  print_message(FATAL, "MigrationException, " + e.to_s)
  exit e.code 
rescue MigSyntaxError => e
  print_message(FATAL, "MigSyntaxError, " + e.to_s)
  printUsage($argdef)
  exit e.code
rescue Interrupt
  print_message(DEBUG, "Interrupted by user")
  writeToSessionFile(@jobDone, @cnt) if @opt['c'] and @init == false
  exit 0
rescue 
  print_message(FATAL, "Caught exception: #{$!.message}\n Backtrace:\n #{$!.backtrace.join("\n")}")
  exit 1
end

