#!/usr/bin/env ruby
# Copyright (C) [2007-2009] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

#This script is to reconfigure LUM after a server ID swap

require 'rubygems'
require 'mig'
include Migration

def getGroupFDN grp
  serverContext = server_context
  host = getldapString
  groups = `ldapsearch -LLL -s sub -x -b "#{serverContext}" "cn=#{grp}" dn -H #{host}`
  if $? != 0
    print_message(FATAL, "Unable to get FDN for group #{grp}. ldapsearch result #{groups}")
    exit 1
  end
  if not groups.nil? and not groups.empty? and groups.include?("dn:")
    firstLine = groups.split("\n", 2)[0]   #dn: cn=www,ou=wgp,o=novell
    fdn = firstLine.split(":", 2)[1]       #cn=www,ou=wgp,o=novell
  elsif not groups.include?("dn:")
    print_message(FATAL, "Unable to get FDN for group #{grp}. ldapsearch result #{groups}")
    exit 1
  end
  return fdn
end

def lumEnableUsersInGroup grpFdn
  host = getldapString
  users = `ldapsearch -LLL -x -H #{host} -b "#{grpFdn}" member`
  if $? != 0
    print_message(FATAL, "Unable to get users for group #{grpFdn}. ldapsearch result #{users}")
    exit 1
  end
  if not users.nil? and not users.empty? and users.include?("member")
    result = []
    users.each_line { | line | 
     result << line
    }
    i = 0
    while i < result.length 
      if result[i].include?("member:") 
        encoded = false
        if result[i].include?("::")
        #the first match is encoded
          a, v = result[i].split("::",2)
          encoded = true
        else
          a, v = result[i].split(":", 2)
        end
        v.strip!
        i = i+1
        while i < result.length and result[i].index(":") == nil
          v << result[i].strip
          i = i + 1
        end
        if encoded
          val = "#{Base64.decode64(v.strip)}"
        else
          val = "#{v.strip}"
        end
        val.gsub!(/"/,"\\\"")
        usrFdn = val.strip
        cmd = "LC_ALL=en_US.UTF-8 namusermod -a \"#{@opt['a']}\" -g \"#{grpFdn}\" \"#{usrFdn}\""
        print_message(INFO, "LUM enabling user #{usrFdn} with command #{cmd}\n")
        retryCount = 0
        max_retry_count=3;
        while retryCount <  max_retry_count
          cmdresult = `#{cmd}`
          if $? != 0 
          # All the members in a LUM enabled group need not be LUM users. 
          # So, ignore the error, if the user does not have LUM attributes
             if cmdresult !=nil && cmdresult.include?("Not a unix user")
               print_message(WARN, "User #{usrFdn} is not a LUM user, skipping LUM enabling for this user.")
               break
             else
               print_message(WARN, "Failed to execute the command #{cmd} with result #{cmdresult} retval #{$?}")
             end
          else
            break
          end
          retryCount= retryCount+1
          exit 1 if retryCount == max_retry_count
          sleep(retryCount*5)
          print_message(INFO, "re-trying the command: #{cmd}.")
        end
     else
	i = i + 1
      end
    end
  end
end


def getLUMGroupsList searchBase, serverName
  host = getldapString
  if not searchBase.nil?
    unixWrkStn = `ldapsearch -LLL -s sub -x -H #{host} -b "#{searchBase}" "(&(objectclass=uamPosixWorkstation)(cn=UNIX Workstation - #{serverName}))" groupMembership`
    if $? != 0 or unixWrkStn.nil? or unixWrkStn.empty? or not unixWrkStn.include?("dn:")
      unixWrkStn = `ldapsearch -LLL -s sub -x -H #{host} "(&(objectclass=uamPosixWorkstation)(cn=UNIX Workstation - #{serverName}))" groupMembership`
    end
  else
    unixWrkStn = `ldapsearch -LLL -s sub -x -H #{host} "(&(objectclass=uamPosixWorkstation)(cn=UNIX Workstation - #{serverName}))" groupMembership`
  end
  if $? != 0 or unixWrkStn.nil? or unixWrkStn.empty?
    print_message(FATAL, "Unable to get UNIX Workstation object. ldapsearch failed. Returned #{unixWrkStn}")
    exit 1
  end
  if unixWrkStn.include?("groupMembership")
    result = []
    unixWrkStn.each_line { | line | 
     result << line
     }
     i = 0
     while i < result.length 
      if result[i].include?("groupMembership:") 
	encoded = false
        if result[i].include?("::")
        #the first match is encoded
          a, v = result[i].split("::",2)
          encoded = true
        else
          a, v = result[i].split(":", 2)
        end
        v.strip!
        i = i+1
        while i < result.length and result[i].index(":") == nil
          v << result[i].strip
          i = i + 1
        end
        if encoded
          val = "#{Base64.decode64(v.strip)}"
        else
          val = "#{v.strip}"
        end
        val.gsub!(/"/,"\\\"")
        puts val.strip
      else
	i = i + 1
      end
    end
  else
    print_message(WARN, "UNIX Workstation object has no groups. ldapsearch returned #{unixWrkStn}")
    exit 1
  end
end
def get_short_name ldap_name 
  #puts "ldap_name: #{ldap_name}"
  index = ldap_name.index(",")
  if index == nil
    index = ldap_name.length
  end
  #puts "index:#{index}"
  name = ldap_name[0, index]
  name  = name[name.index("=")+1,name.length]
  return name
end

def checkUsersInLUMGroup grpFdn
  host = getldapString
  users = `ldapsearch -LLL -x -H #{host}  -b "#{grpFdn}" member`
  if $? != 0
    # Show error only for default groups and exit with error. Fix for #741597
    if (grpFdn.include?("cn=admingroup") or grpFdn.include?("cn=www") or grpFdn.include?("cn=novlxtier"))
      print_message(FATAL, "Unable to get users for group #{grpFdn}. ldapsearch result #{users}")
      exit 1
    else
      # For custom LUM groups, we will only warn and exit. Fix for #741597
      print_message(WARN, "Unable to get users for group #{grpFdn}. ldapsearch result #{users}")
      exit 0
    end
  end
  if not users.nil? and not users.empty? and users.include?("member")
    result = []
    users.each_line { | line | 
     result << line
    }
    i = 0
    while i < result.length 
      if result[i].include?("member:") 
	encoded = false
        if result[i].include?("::")
        #the first match is encoded
          a, v = result[i].split("::",2)
          encoded = true
        else
          a, v = result[i].split(":", 2)
        end
        v.strip!
        i = i+1
        while i < result.length and result[i].index(":") == nil
          v << result[i].strip
          i = i + 1
        end
        if encoded
          val = "#{Base64.decode64(v.strip)}"
        else
          val = "#{v.strip}"
        end
        val.gsub!(/"/,"\\\"")
	usrFdn = val.strip
        usrShortName = get_short_name usrFdn
        cmd = "id \"#{usrShortName}\""
        print_message(INFO, "Checking LUM enabling for user: #{usrShortName}.")
        result1 = `#{cmd}`
        if $? != 0
          print_message(WARN, "Failed to LUM enable user: #{usrShortName}.")
          print_message(WARN, "Command #{cmd} : failed with error #{result1}.")
        end    
     else
	i = i + 1
      end
    end
  end
end

def getldapString
  if @opt['use-unsecure-ldap'] == nil
    part_string = "ldaps"
  else
    part_string = "ldap"
  end
  if @opt['ldap-port'] == nil
    host = "#{part_string}:\/\/#{@opt['S']}"
  else
    host = "#{part_string}:\/\/#{@opt['S']}:#{@opt['ldap-port']}"
  end
  return host
end

def verifyLUMGroup grpfdn
   grpShortName = get_short_name grpfdn
   cmd = "/usr/bin/namgrouplist \"#{grpShortName}\""
   print_message(INFO, "Checking LUM enabling for group: #{grpShortName} with command #{cmd}.")
   result = `#{cmd}`
   # Show error only for default groups. Fix for #741597
   if (grpfdn.include?("cn=admingroup") or grpfdn.include?("cn=www") or grpfdn.include?("cn=novlxtier"))
     if $? != 0
       print_message(FATAL, "Failed to LUM enable group: #{grpShortName}.")
       print_message(FATAL, "Command #{cmd} : failed with error #{result}.")
       exit 1
     end
   else
     # For custom LUM groups, we will only warn. Fix for #741597
     if $? != 0
       print_message(WARN, "Failed to LUM enable group: #{grpShortName}.")
     end
   end
   checkUsersInLUMGroup grpfdn
end

#main
def main
  $argdef = [
    ['H','hostname', "Specify the hostname/workstation name",ParseArgText, true],
    ['a', 'adminFDN', "Specify, in LDAP format, the administrator's name", ParseArgText, true],
    ['S', nil, "Specify the IP address of the preferred LDAP eDirectory server to be contacted",ParseArgText, true],
    [nil, 'use-unsecure-ldap', "Specify to use unsecure LDAP for all LDAP commands", ParseArgBool, false],
    [nil, 'ldap-port', "Specify the port where LDAP server is listening", ParseArgText, false],
    [nil, 'grp', "Specify the group to be modified", ParseArgOrd, false],
    ['p', 'pwd', "Specify the administrator's password", ParseArgText,false],
    ['l','list',"Specify to list LUM enabled user and groups FDN",ParseArgBool,false],
    [nil,'check',"Specify to verify LUM enabled user and groups",ParseArgBool,false]
]

  initLog(false, "nam-grpmod.rb")
  (@opt, extraargs) = parseargs(ARGV, $argdef)

  ENV['LC_ALL'] = "en_US.UTF-8"

  if @opt['p']
        ENV['LUM_PWD'] = @opt['p']
  end
  if ENV['LUM_PWD'] == nil
    print_message(FATAL, "Invalid Arguments: Password is not specified")
    exit 1
  end
 
  wrkStn_cn = server_name()
  if wrkStn_cn == nil or wrkStn_cn.empty?
    print_message(FATAL, "Failed to get NCP Server object DN from eDirectory")
    exit 1
  end
  wrkStn = wrkStn_cn[wrkStn_cn.index("=")+1, wrkStn_cn.length]

  if @opt['l']
    searchBaseStr = `/usr/bin/namconfig get base-name`
    if searchBaseStr == nil or searchBaseStr.empty?
        print_message(FATAL, "Failed to get LUM search base using namconfig get base-name")
        exit 1
    end
    searchBase =  searchBaseStr[searchBaseStr.index("=")+1, searchBaseStr.length]
    searchBase.strip!
    getLUMGroupsList searchBase,@opt['H']
  else
    if @opt['grp'] == nil
      print_message(FATAL, "Invalid Arguments: option 'grp' is not specified")
      exit 1
    end
    if @opt['grp'].include?("cn=")
      fdn = @opt['grp'].dup
    else
      fdn = getGroupFDN(@opt['grp'])
    end
 
 
    if @opt['check'] != nil
      verifyLUMGroup fdn
    else
      #cmd = "namgroupmod -a #{@opt['a']}   -w #{@opt['p']} -W #{@opt['H']} #{fdn}"
      # Password is passed using the ENV variable LUM_PWD  
      cmd = "LC_ALL=en_US.UTF-8 namgroupmod -a \"#{@opt['a']}\"  -W \"#{@opt['H']}\" \"#{fdn}\""
      print_message(INFO, "LUM enabling group #{fdn} with command #{cmd}\n")
      retryCount = 0
      max_retry_count = 3;
      while retryCount < max_retry_count
        result = `#{cmd}`
        # Show error only for default groups and re-try. Fix for #741597
        if (fdn.include?("cn=admingroup") or fdn.include?("cn=www") or fdn.include?("cn=novlxtier")) 
          if $? != 0
            print_message(ERROR, "Failed to execute the command #{cmd} with result #{result}")
          else
            break
          end
        else
        # For custom LUM groups, we will only warn and no re-try. Fix for #741597
          if $? != 0
            print_message(WARN, "Failed to execute the command #{cmd} with result #{result}")
          end
          break
        end
        retryCount = retryCount + 1
        exit 1 if retryCount == max_retry_count
        sleep(retryCount*5)
        print_message(INFO, "re-trying the command: #{cmd}.")
      end
      # No need to LUM enable all users in each group, as they are already
      # LUM enabled. All we need to do is LUM enable groups.
      # Fix for BugZilla#741597
      #lumEnableUsersInGroup fdn
    end
  end
end

begin
  main
rescue SystemCallError => failed  
  print_message(FATAL, "SystemCallError, #{failed.message}")
  exit failed.errno
rescue MigrationException => e 
  print_message(FATAL, "MigrationException, " + e.to_s)
  exit e.code 
rescue MigSyntaxError => e
  print_message(FATAL, "MigSyntaxError, " + e.to_s)
  printUsage($argdef)
  exit e.code
rescue Interrupt
  print_message(DEBUG, "Interrupted by user")
  writeToSessionFile(@jobDone, @cnt) if @opt['c'] and @init == false
  exit 0
rescue 
  print_message(FATAL, "Caught exception: #{$!.message}\n Backtrace:\n #{$!.backtrace.join("\n")}")
  exit 1
end
