#!/usr/bin/env ruby
# Copyright (C) [2007-2008] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

#This script is to reconfigure LUM after a server ID swap

require 'rubygems'
require 'mig'
require 'logger'
include Migration

#main
def main
  $argdef = [
    ['a', 'adminFDN', "Specify, in LDAP format, the administrator's name", ParseArgText, true],
    [nil, 'use-unsecure-ldap', "Specify to use unsecure LDAP for all LDAP commands", ParseArgBool, false],
    [nil, 'ldap-port', "Specify the port where LDAP server is listening", ParseArgText, false],
    ['S', nil, "Specify the IP address of the preferred LDAP eDirectory server to be contacted", ParseArgText, true],
    ['p', 'pwd', "Specify the administrator's password", ParseArgText,false],
    ['u', 'unixconfig',"Specify the unix config objects base dn",ParseArgText,false],
    ['R', nil, "Specify a comma-separated list of alternative LDAP servers", ParseArgText]
  ]
  sleep(10)
  initLog(false, "nam-reconf.rb")
  (@opt, extraargs) = parseargs(ARGV, $argdef)
  ENV['LC_ALL']="en_US.UTF8"
 
  unixConfigContext = @opt['u']
#  print_message(FATAL,unixConfigContext.to_s)
  serverContext = server_context
if unixConfigContext == nil or unixConfigContext == ""
    unixConfigContext = serverContext
  end
  if @opt['S']
    server = @opt['S']
  else
    server = IPSocket.getaddress(Socket.gethostname)
  end
 if @opt['p']
    ENV['LUM_PWD'] = @opt['p']
 end
 if ENV['LUM_PWD'] == nil
   print_message(FATAL, "Invalid Arguments: Password is not specified")
   exit 1
 end
 if @opt['R']
    alternateServer = @opt['R']
 end
 if alternateServer == nil or alternateServer == ""
    cmd = "LC_ALL=en_US.UTF-8 /usr/bin/namconfig add -a \"#{@opt['a']}\"  -r \"#{unixConfigContext}\" -w \"#{serverContext}\" -S #{server}"
 else
    cmd = "LC_ALL=en_US.UTF-8 /usr/bin/namconfig add -a \"#{@opt['a']}\"  -r \"#{unixConfigContext}\" -w \"#{serverContext}\" -R \"#{alternateServer}\" -S #{server}"
 end
 # Password is passed using the Environmental Varaible LUM_PWD
 #cmd = "/usr/bin/namconfig add -a #{@opt['a']} -p #{@opt['p']} -r #{unixConfigContext} -w #{serverContext} -S #{server}"

  if @opt['use-unsecure-ldap'] == nil
    cmd = cmd + " -l #{@opt['ldap-port']}"
  else
    cmd = cmd + ":#{@opt['ldap-port']}"
  end
  # lets print the namconfig command, so that user knows what to execute when it fails
  print_message(INFO, "executing command: #{cmd}\n")
  result = `#{cmd}`
  if $? != 0
    print_message(FATAL, "Failed to execute the command: #{cmd} with result: #{result}")
    exit 1
  end
end

begin
  main
rescue SystemCallError => failed  
  print_message(FATAL, "SystemCallError, #{failed.message}")
  exit failed.errno
rescue MigrationException => e 
  print_message(FATAL, "MigrationException, " + e.to_s)
  exit e.code 
rescue MigSyntaxError => e
  print_message(FATAL, "MigSyntaxError, " + e.to_s)
  printUsage($argdef)
  exit e.code
rescue Interrupt
  print_message(DEBUG, "Interrupted by user")
  writeToSessionFile(@jobDone, @cnt) if @opt['c'] and @init == false
  exit 0
rescue 
  print_message(FATAL, "Caught exception: #{$!.message}\n Backtrace:\n #{$!.backtrace.join("\n")}")
  exit 1
end
