#!/usr/bin/env ruby
# Copyright (C) [2007-2008] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

#This script is to reconfigure LUM after a server ID swap

require 'rubygems'
require 'mig'
include Migration


def getUserFDN usr
  serverContext = server_context
  host = getldapString
  groups = `ldapsearch -LLL -s sub -x -H #{host} -b "#{serverContext}" "cn=#{usr}" dn`
  if $? != 0
    puts "ldapsearch failed for #{usr}"
    exit 1
  end
  if not groups.nil? and not groups.empty? and groups.include?("dn:")
    firstLine = groups.split("\n", 2)[0]   #dn: cn=www,ou=wgp,o=novell
    usrfdn = firstLine.split(":", 2)[1]       #cn=www,ou=wgp,o=novell
  elsif not groups.include?("dn:")
    puts "ldapsearch failed for #{usr}"
    exit 1
  end
  return usrfdn
end

def getGroupFDN grp
  host = getldapString
  groups = `ldapsearch -LLL -s sub -x -H #{host} "cn=#{grp}" dn`
  if $? != 0
    puts "ldapsearch failed with #{grp}"
    exit 1
  end
  if not groups.nil? and not groups.empty? and groups.include?("dn:")
    firstLine = groups.split("\n", 2)[0]   #dn: cn=www,ou=wgp,o=novell
    fdn = firstLine.split(":", 2)[1]       #cn=www,ou=wgp,o=novell
  elsif not groups.include?("dn:")
    puts "ldapsearch failed with #{grp}"
    exit 1
  end
  return fdn
end

def getldapString 
  if @opt['use-unsecure-ldap'] == nil
    part_string = "ldaps"
  else
    part_string = "ldap"
  end
  if @opt['ldap-port'] == nil
    host = "#{part_string}:\/\/#{@opt['H']}"
  else
    host = "#{part_string}:\/\/#{@opt['H']}:#{@opt['ldap-port']}"
  end
  return host
end

#main
def main
  $argdef = [
    ['H','hostname', "Specify the hostname or IP address of the preferred LDAP eDirectory server to be contacted",ParseArgText,true],
    ['a', 'adminFDN', "Specify, in LDAP format, the administrator's name", ParseArgText, true],
    [nil, 'use-unsecure-ldap', "Specify to use unsecure LDAP for all LDAP commands", ParseArgBool, false],
    [nil, 'ldap-port', "Specify port where LDAP server is listening", ParseArgText, false],
    [nil, 'grp', "Specify the group to be modified", ParseArgOrd, true],
    [nil, 'usr', "Specify the user to be modified", ParseArgOrd, true],
    ['p', 'pwd', "Specify the administrator's password", ParseArgText,false]
  ]

  initLog(false, "nam-usrmod.rb")
  (@opt, extraargs) = parseargs(ARGV, $argdef)
  if @opt['p']
        ENV['LUM_PWD'] = @opt['p']
  end
  if ENV['LUM_PWD'] == nil
    print_message(FATAL, "Invalid Arguments: Password is not specified")
    exit 1
  end
 
  wrkStn_cn = server_name()
  wrkStn = wrkStn_cn[wrkStn_cn.index("=")+1, wrkStn_cn.length]

  fdn = getGroupFDN(@opt['grp'])
  usrfdn = getUserFDN(@opt['usr'])	 

  #cmd = "namusermod -a #{@opt['a']}   -w #{@opt['p']} -g #{fdn} #{usrfdn}"
  # Password is passed using ENV variable LUM_PWD  
  cmd = "namusermod -a \"#{@opt['a']}\" -g \"#{fdn}\" \"#{usrfdn}\""

  system(cmd)
end

begin
  main

rescue SystemCallError => failed  
  print_message(FATAL, "SystemCallError, #{failed.message}")
  exit failed.errno
rescue MigrationException => e 
  print_message(FATAL, "MigrationException, " + e.to_s)
  exit e.code 
rescue MigSyntaxError => e
  print_message(FATAL, "MigSyntaxError, " + e.to_s)
  printUsage($argdef)
  exit e.code
rescue Interrupt
  print_message(DEBUG, "Interrupted by user")
  writeToSessionFile(@jobDone, @cnt) if @opt['c'] and @init == false
  exit 0
rescue 
  print_message(FATAL, "Caught exception: #{$!.message}\n Backtrace:\n #{$!.backtrace.join("\n")}")
  exit 1
end
