#!/bin/bash
# Copyright (C) [2012] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.

admin="";
password="";
new_nssAdminUser="";
server_context="";
source_server="";
NSSADMIN_CONFIG_FILE="/var/opt/novell/nss/.nss.dat";
NSSADMIN_CONFIG_FILE_SRC="/tmp/.nss.dat";
NSSADMIN_INSTALL_BIN="/sbin/nssAdminInstall";
#This script is used to update the nssAdmin for ID transfer
#Returns 0 for successful update, 1 for failed attempt, -1 for not attempting

usage()
{
cat << EOF
usage: $0 -a <admin name> -p <admin password> -s <source server [OES/NW]> -o <nss admin object name with context> [-c <server context>]

-a, -p, and -s arguments are required.
-c is an optional argument. It is required only when the nss admin user is created outside the server context.
-o is required when source server(-s) is Netware(NW).

example: $0 -a 'admin.cape breton' -p test -s NW -o 'nssAdminUser.cape breton' 
EOF
exit 1;
}

while getopts "a:p:o:s:c:" opt
do
	case $opt in 
		a)
			admin="$OPTARG";
			;;
		p)
			password=$OPTARG;
			;;
		o)
			new_nssAdminUser=$OPTARG;
			;;
		c)
			server_context=$OPTARG;
			;;
		s)
			source_server=$OPTARG;
			;;
		?)
			usage
			;;
	esac
done

if [ -z $admin ] || [ -z $source_server ] || [ $source_server = "NW" -a  -z "$new_nssAdminUser" ] || [ $source_server = "OES" -a  -n "$new_nssAdminUser" ]
then
     usage
fi

#If Admin password is not passed through command line, it should be passed through environment variable OES_ADMIN_PWD
if test "$password" = ""
then
        password="$OES_ADMIN_PWD"
        if test "$password" = ""
        then
                echo "Error: eDir Admin password is not provided"
                usage
        fi
fi

#If NSS pattern is not installed or configured, don't even attempt this operation and return success because there is nothing to do
#Don't perform admin repair if any one file doesn't exists, fix for BugZilla#768348
if ! [ -f $NSSADMIN_INSTALL_BIN ] || ! [ -f $NSSADMIN_CONFIG_FILE ];
then
	echo "INFO: nssAdmin repair is not required as NSS is not installed";
    #Never return negative value from shell script. Changing the return value to some positive number other than 1
	exit 2;
fi

# Deleting the existing NSS Admin user
$NSSADMIN_INSTALL_BIN -a "$admin" -p "$password" --delete
if [ $? -ne 0 ]
then
	echo "Error: Temporary NSS Admin user object deletion failed. Delete this object manually";
fi

# Assigning the new NSS Admin user
if [ $source_server = "NW" ]
then
	if [ -z $server_context ]
	then
		$NSSADMIN_INSTALL_BIN -a $admin -p "$password" -o $new_nssAdminUser
	else
		$NSSADMIN_INSTALL_BIN -a $admin -p "$password" -o $new_nssAdminUser -c $server_context
	fi

	if [ $? -ne 0 ]
	then
    		echo "Error: NSS Admin user object creation failed.\n";
		exit 1;
	fi
elif [ $source_server = "OES" ]
then
	if [ -f $NSSADMIN_CONFIG_FILE_SRC -a -f $NSSADMIN_CONFIG_FILE ]
	then
		cp $NSSADMIN_CONFIG_FILE_SRC $NSSADMIN_CONFIG_FILE;
	else
		echo "Error: NSS Config file does not exist. Please copy the .nss.dat file from the sources OES server to $NSSADMIN_CONFIG_FILE.\n";
		exit 1;
	fi
fi
exit 0;
