#!/usr/bin/env ruby

# (C) Copyright 1995 - 2021 Micro Focus or one of its affiliates.
 
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions contained
# herein. The information contained herein is subject to change without notice.
 
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items  are licensed
# to the U.S. Government under vendor's standard commercial license.

# Copyright (C) [2007-2008] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
require 'rubygems'
require 'etc'
require 'expect'
require 'logger'
require 'open3'
require 'base64'
require 'mig'

include Migration

VOL_GUID_FILE='volguids.xml'
POOL_GUID_FILE='poolguids.xml'
NOVELL_NSS_BIN='/usr/lib/systemd/system/novell-nss.service'
NSSADMIN_CONFIG_FILE='/var/opt/novell/nss/.nss.dat'
NSSADMIN_INSTALL_BIN='/sbin/nssAdminInstall'


def get_pool_guid poolName
  localip = getLocalIPAddress
  if localip == nil or localip == ""
    print_message(FATAL,"Failed to get Local Server Name");  
    exit 1
  end

  host = "ldaps://"+localip
  userDN = @opt['a']
  searchString=format("(&(%s_%s_POOL)(objectClass=nssfsPool))", $host_name,poolName)

    ldapcmd = "LC_ALL=en_US;ldapsearch -LLL -s sub -H \"#{host}\" -x -D \"#{userDN}\"  \"#{searchString}\"  \"guid\" -W "

    print_message(INFO, "Executing #{ldapcmd}")
    options = {}
    options[:password] = ENV['VOLGUID_PWD']
    ldap_result = executeLdapCmd(ldapcmd, options)


    if ldap_result == nil or ldap_result == "" or ldap_result.length == 0
      print_message(WARN, "Failed to get guid for pool #{poolName}")
      $nonExistingPools << poolName
      return
    end
    print_message(INFO,format("LDAP Query Result: %s\n",ldap_result))
    ldap_result.each do |single|
    if single != nil and single != ""  and single.include?("guid::")
        volguid = single.split("::")
		guid = volguid[1].strip
        decodedGUIDStr = Base64.decode64(guid)
		# Below code is added to provide the fix for bug #1170754
        decodedGUID = decodedGUIDStr.unpack('C*')
	if decodedGUID.size  == 16
 	  $outfile.write format("\t<poolName>%s</poolName>\n", poolName)
         #A unconvetional way to convert the LDAP search GUID format to NSS tool format. Need to look at later
          $outfile.write format("\t<poolGUID>%02x%02x%02x%02x-%02x%02x-%02x%02x-%02x-%02x-%02x%02x%02x%02x%02x%02x</poolGUID>\n", decodedGUID[3],decodedGUID[2],decodedGUID[1],decodedGUID[0],decodedGUID[5],decodedGUID[4],decodedGUID[7],decodedGUID[6],decodedGUID[8],decodedGUID[9],decodedGUID[10],decodedGUID[11],decodedGUID[12],decodedGUID[13],decodedGUID[14],decodedGUID[15]);
        else       
         print_message(WARN, "Failed to decode GUId attribute \n")
        end
    end
  end
end


def get_pool_guids
  pools = get_nss_pool_list
  if pools != nil
    $outfile.write "<listPools>\n"
    pools.each do  |poolName|
      print_message(INFO, "Getting GUID for NSS Pool " + poolName.to_s)
      get_pool_guid poolName
    end
    $outfile.write "</listPools>\n"
  else
    print_message(WARN, "Could not locate NSS Pools\n")
  end
end



def get_vol_guid volname
  localip = getLocalIPAddress
  if localip == nil or localip == ""
    print_message(FATAL,"Failed to get Local Server Name");  
    exit 1
  end

  host = "ldaps://"+localip
  userDN = @opt['a']
  searchString=format("(&(%s_%s)(objectClass=Volume))", $host_name,volname)

  ldapcmd = "LC_ALL=en_US;ldapsearch -LLL -s sub -H \"#{host}\" -x -D \"#{userDN}\" \"#{searchString}\"  \"guid\" -W"
  print_message(INFO,format("Executing %s\n",ldapcmd))
  options = {}
  options[:password] = ENV['VOLGUID_PWD']

  ldapresult = executeLdapCmd(ldapcmd, options)
  if ldapresult == nil or ldapresult == "" or ldapresult.length == 0
    print_message(WARN, "Failed to get guid for Volume #{volname}")
    $nonExistingVolumes << volname
    return 
  end
  print_message(INFO,format("LDAP Query Result: %s\n",ldapresult))
  ldapresult.each do |single|
    if single != nil and single != "" and single.include?("guid:")
      volguid = single.split("::")
      guid = volguid[1].strip
      decodedGUIDStr = Base64.decode64(guid)
	  # Below code is added to provide the fix for bug #1170754
      decodedGUID = decodedGUIDStr.unpack('C*')
      if decodedGUID.size  == 0
	  print_message(WARN, "Failed to decode GUId attribute \n")
      else       
          $outfile.write format("\t<volumeName>%s</volumeName>\n", volname)
         #A unconvetional way to convert the LDAP search GUID format to NSS tool format. Need to look at later
          $outfile.write format("\t<volumeGUID>%02x%02x%02x%02x-%02x%02x-%02x%02x-%02x-%02x-%02x%02x%02x%02x%02x%02x</volumeGUID>\n", decodedGUID[3],decodedGUID[2],decodedGUID[1],decodedGUID[0],decodedGUID[5],decodedGUID[4],decodedGUID[7],decodedGUID[6],decodedGUID[8],decodedGUID[9],decodedGUID[10],decodedGUID[11],decodedGUID[12],decodedGUID[13],decodedGUID[14],decodedGUID[15]);
      end
    elsif single.include?("dn:")
     $volDNHash[volname] = single.split(":")[1]
    end
  end
end

def update_volume_mountpoints
  host = getLocalIPAddress
  userDN = @opt['a'] 

  $volDNHash.each_pair {|volume, voldn| 

  #Note: ldapmodify was failing if the voume object already has the attribute linuxNCPMountPoint
  #so, first delete the attribute and add the attribute back to
  volume, mntpt = get_nss_vol_and_mnt_point_from_vol volume
  print_message(INFO,"The volume and the mount point is #{volume} and #{mntpt}")

  ldap_str = "dn: #{voldn}\ndelete:  linuxNCPMountPoint\n"
  print_message(INFO, "Deleting mount point attribute #{volume}")
  result = Migration.ldapmod host, userDN, ldap_str, ENV['VOLGUID_PWD']
  print_message(INFO,"Result of ldapmod for deleting the attribute is #{result}")

  # In some of the huge tree environments, deleting the attribute takes more time. So before proceeding
  # with the next step, lets wait for few seconds for the delete operation to complete. Hence adding the delay
  # in the next line.
  # This is added to provide the fix for bug #769239
  sleep(5)
  ldap_str = "dn: #{voldn}\nadd:  linuxNCPMountPoint\nlinuxNCPMountPoint: NSS     #{mntpt}\n"
  print_message(INFO, "Updating #{volume} #{mntpt} ")
  result = Migration.ldapmod host, userDN, ldap_str, ENV['VOLGUID_PWD']
  sleep(5)
  print_message(INFO,"Result of ldapmod for adding the attribute is #{result}")
  
  # Now query ldap and check if the linuxNCPMountPoint attribute is set or not. If not set, log the warning message for the same.
  # This is added to provide the fix for bug #769239
  hostURI = "ldaps://" + host
  source_server_name = server_name(host)
  searchString = source_server_name + "_" + "*"
  print_message(INFO, "ldapsearch command executed as \"ldapsearch -LLL -s sub -H #{hostURI} -x -D \"#{@opt['a']}\" \"(&(#{searchString})(objectClass=Volume))\" linuxNCPMountPoint -W\"")
  cmd = "LC_ALL=en_US ldapsearch -LLL -s sub -H #{hostURI} -x -D \"#{@opt['a']}\" \"(&(#{searchString})(|(objectClass=Volume)(objectClass=ndsVolume)))\" linuxNCPMountPoint -W"
  options = {}
  options[:password] = ENV['VOLGUID_PWD']
  result = executeLdapCmd(cmd, options)
  print_message(INFO, "The result of ldapsearch is #{result}")
  i=0
  isLinuxNCPMountPointSet = false
  while i < result.length
     if result[i].include?("linuxNCPMountPoint") and result[i].include?("#{volume}")
       isLinuxNCPMountPointSet = true
       break
     end
     i=i+1
  end
  if not isLinuxNCPMountPointSet
    print_message(WARN, "The linuxNCPMountPoint attribute is not set for #{volume}. Please set this attribute manually using iManager.")
  end

 }
end

def get_vol_guids
  volumes = get_nss_volume_list
  if volumes != nil
    $outfile.write "<listVolumes>\n"
    volumes.each do  |volume|
      print_message(INFO, "Getting GUID for Volume " + volume.to_s)
      get_vol_guid volume
    end
    $outfile.write "</listVolumes>\n"
  else
    print_message(INFO,"Could not locate NSS voumes on the server, Volume list is empty\n")
  end
end

def updateGUIDsToNSS
#Write the commands to update the GUIDs using the NSS tools
=begin pfType = `uname -i`
  nsstool = ""
  if pfType.include?"x86_64"
    nsstool = "/opt/novell/migration/sbin/mpvguid64"
  else
    nsstool = "/opt/novell/migration/sbin/mpvguid32"
  end
=end
  nsstool = "/opt/novell/migration/sbin/mpvguid"
  if !File.exist?(nsstool)
    print_message(WARN,"Failed to locate NSS volume repair tool #{nsstool}")
  return
  end
  if File.exist?($poolOutFileName)
    result  = `#{nsstool} put pool #{$poolOutFileName}`
    print_message(INFO,"Updated NSS Pool objects successfully")
    print_message(INFO,result)
  else
    print_message(WARN, "Pool GUID file does not exist\n")
  end
  if File.exist?($poolOutFileName)
    result  = `#{nsstool} put volume #{$volOutFileName}`
    print_message(INFO,"Updated NSS volume objects successfully")
    print_message(INFO,result)
  else
   print_message(WARN, "Volume GUID file does not exist\n");
  end
end

def checkAndStartNSS
   
  #Check for NSS pattern. If NSS is neither installed nor configured, don't continue repair. Fix for BugZilla#824594
  if !File.exists?(NOVELL_NSS_BIN) || !File.exists?(NSSADMIN_CONFIG_FILE) || !File.exists?(NSSADMIN_INSTALL_BIN)
    print_message(INFO,"Volume repair is not required as NSS is not installed.\n")
    exit 0
   end

# check if NSS is running. Repair volume object GUIDs if NSS is running. Show a message to run the script to reapair volume objects.
  print_message(INFO, "Checking NSS status ...")
  nssCmdResponse = `/sbin/rcnovell-nss status`
  if nssCmdResponse == nil || nssCmdResponse == ""
    print_message(WARN,"Failed to check NSS status. Start NSS using \"rcnovell-nss start\" and run volume repair script /opt/novell/migration/sbin/serveridswap/scripts/repair/volrepair.rb to repair the NSS Pool and Volume objects\n")
    exit 1
  end

  if nssCmdResponse.include?("unused")
    print_message(INFO,"Starting NSS using the command \"rcnovell-nss start\".\nTime taken to execute this command depends on the NSS startup operations.\nNo log messages will be updated during the execution.\nExecuting........\n ")
    # start NSS service using the command rcnovell-nss start
    nssCmdResponse = `/sbin/rcnovell-nss start`
    print_message(INFO,nssCmdResponse)
  end
  # check if NSS is up and running
  nssCmdResponse = `/sbin/rcnovell-nss status`
  if nssCmdResponse == nil || nssCmdResponse == "" || nssCmdResponse.include?("unused")
    print_message(WARN,"Failed to start NSS. \n\tStart NSS using \"rcnovell-nss start\" and run volume repair script \"/opt/novell/migration/sbin/serveridswap/scripts/repair/volrepair.rb\" to repair the NSS Pool and Volume objects\n")
    exit 1
  end

end

def main
 $argdef = [
    ['a', 'adminFDN', "The administrator's FDN specified in LDAP format", ParseArgText, true],
    ['p', 'pwd', "The administrator's password", ParseArgText, false],
    ['f', 'project-path', "Location to store the pool and volume guid list file", ParseArgText,true],
    [nil, 'debug', "Enalbe dubug", ParseArgBool, false],
    ParseArgHelp,
    ParseArgUsage
  ]
 volguidCommand = "#{$0}"  # name of the script.
 
 debugOpt = false
 $*.each do |arg|
   if arg.strip == "--debug"
      debugOpt = true
   end
   volguidCommand += " #{arg}" # Form the actual command executed.
 end
  initLog(debugOpt, "volrepair")
  print_message(DEBUG, "volrepair command started at #{`date +%d-%m-%y\\ %H:%M:%S`}")
  print_message(DEBUG, "volrepair command executed as: #{volguidCommand}") 
  
  (@opt, extraargs) = parseargs(ARGV, $argdef)
  
  # Check if env variable is set. If not check for option 'p' in the arguments passed. If not present prompt the user for password.
 if ENV['VOLGUID_PWD'] == nil or ENV['VOLGUID_PWD'] == ""
  if not @opt['p']
    flag = true
    $stderr.print "Enter #{@opt['a']} password: "
       if $stdin.isatty
       `stty -echo`
       end
       @opt['p'] = $stdin.gets.chomp
       puts "\n" # to show prompt in next line
       if $stdin.isatty
       `stty echo`
       end
       # Alert the user if he enters empty password
       if @opt['p'].empty? or @opt['p'] == nil
         print_message(FATAL, "Invalid Arguments: Password is empty")
	 exit 1
       end
  end
 end
	
  # Validate arguments
  if @opt['p']
        ENV['VOLGUID_PWD'] = @opt['p']
  end

  # check and start NSS
  checkAndStartNSS

  # get local host name
  $host_name = server_name
  $volDNHash = Hash.new
  $nonExistingPools = Array.new
  $nonExistingVolumes = Array.new
  # get the list of NSS pools and GUIDs from eDirectory
  $poolOutFileName = @opt['f']+"/"+POOL_GUID_FILE;
  $outfile = File.new($poolOutFileName, File::CREAT|File::TRUNC|File::WRONLY, 0600)
  get_pool_guids
  $outfile.close
  # get list of NSS volumes and GUIDs from eDirectory
  $volOutFileName = @opt['f']+"/"+VOL_GUID_FILE;
  $outfile = File.new($volOutFileName, File::CREAT|File::TRUNC|File::WRONLY, 0600)
  get_vol_guids
  $outfile.close
  # Update the eDirectory object GUIDs to the file system
  updateGUIDsToNSS
  # Update the eDirectory objects with the file system mountpoints
  update_volume_mountpoints
  if $nonExistingPools.length > 0
    print_message(WARN, "The following NSS Pools does not exist on the source server. Use \"nssmu\" option \"Update NDS\" for these Pools to repair.\n")
    $nonExistingPools.each do |nePool|
      print_message(WARN,"  #{nePool}")
    end
  end
 if $nonExistingVolumes.length > 0
    print_message(WARN, "The following NSS Volumes does not exist on the source server. Use \"nssmu\" option \"Update NDS\" for these Volumes to repair.\n")
    $nonExistingVolumes.each do |neVolume|
      print_message(WARN,"  #{neVolume}")
    end
  end
end 


begin 
main
rescue SystemCallError => failed  
  print_message(FATAL, "SystemCallError, #{failed.message}")
  exit failed.errno
rescue MigrationException => e 
  print_message(FATAL, "MigrationException, " + e.to_s)
  exit e.code 
rescue MigSyntaxError => e
  print_message(FATAL, "MigSyntaxError, " + e.to_s)
  printUsage($argdef)
  exit e.code
rescue Interrupt
  print_message(DEBUG, "Interrupted by user")
  writeToSessionFile(@jobDone, @cnt) if @opt['c'] and @init == false
  exit 0
rescue LdapAuthError => e
  print_message(FATAL, "Ldap Authentication Error, " + e.to_s)
  exit e.code
rescue  
  print_message(FATAL, "Caught exception: #{$!.message}\n Backtrace:\n #{$!.backtrace.join("\n")}")
  exit 1
ensure
  puts "\n" #shows the prompt in next line if user presses Ctrl+c
  if $stdin.isatty
   `stty echo`
  end
end

