#!/usr/bin/env ruby

# (C) Copyright 1995 - 2021 Micro Focus or one of its affiliates.
 
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions contained
# herein. The information contained herein is subject to change without notice.
 
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items  are licensed
# to the U.S. Government under vendor's standard commercial license.

# Copyright (C) [2008-2009] Novell, Inc.  All Rights Reserved.

# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# IT MAY NOT BE USED, COPIED, DISTRIBUTED, DISCLOSED, ADAPTED, PERFORMED,
# DISPLAYED, COLLECTED, COMPILED, OR LINKED WITHOUT NOVELL'S PRIOR WRITTEN
# CONSENT.  USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD
# SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.

# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE, AND NON-INFRINGEMENT. NOVELL, THE AUTHORS OF THE WORK,
# AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY CLAIM, DAMAGES,
# OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT, OR OTHERWISE,
# ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER
# DEALINGS IN THE WORK.
require 'rubygems'
require 'etc'
require 'expect'
require 'logger'
require 'open3'
require 'mig'
include Migration
TIME_OUT = 300 #5 minutes

def mig_mount_volume( source_host, source_user, password, volname, time_out = TIME_OUT)

   Migration.ncl_mount( source_host, source_user, password, @opt['f'], volname, time_out) 
   if not File.exist?("#{@opt['f']}/#{volname}")
    print_message(ERROR, "Failed to mount volume #{volname} for server #{source_host}")
   # raise SystemCallError.new("Failed to mount volume #{volname} for server #{source_host} .",Migration::EPWD)
    return 1
   end
   return 0
end

# unmouts all mounted volumes
def unmount_all_volumes
  print_message(INFO,"unmounting all mounted volumes")
  ncl_umount(@opt['s'],@opt['f'])
end

#This method gets the List of Cluster volumes on NetWare cluster resource
def getClusterVolumeListOnNetWare volumes 

  # Incase of NetWare cluster perform the following to get the list of cluster volumes.
  # 1. Mount _ADMIN on the source path
  # 2. check for <sourcepathh>/_ADMIN/Novell/Cluster/PoolConfig.xml
  #    PoolConfig.xml file exists iff it has cluster volumes
  # 3. Extract cluster vols and write to an array

  clusVolArr = []
  if volumes.size == 0 or !volumes.to_s.include?("_ADMIN")
    return clusVolArr
  end
  print_message(INFO, "Mounting Volume = _ADMIN\n")
  begin
   retVal = mig_mount_volume @opt['s'], @adminName,@opt['p'], "_ADMIN"
   print_message(ERROR, "Failed to mount _ADMIN volume. Could not identify cluster volumes") if retVal != 0
  rescue SystemCallError => failed  
    print_message(FATAL, "SystemCallError, #{failed.message}")
  rescue MigrationException => e 
    print_message(FATAL, "MigrationException, " + e.to_s)
  rescue 
    print_message(FATAL, "Failed to mount volume _ADMIN Caught exception: #{$!.message}\n Backtrace:\n ")
  end
  
  if File.exist?("#{@opt['f']}/_ADMIN/Novell/Cluster/PoolConfig.xml")
    File.readlines("#{@opt['f']}/_ADMIN/Novell/Cluster/PoolConfig.xml").each do |line|
      if line =~ /<volume>(.*)<\/volume>/
        print "cluster volume name = #{$1}\n"
        # Below line is commented. Use this line if you want a exact match
        #if volumes.to_s =~ /.*(#{$1}).*/
        if volumes.to_s.include?($1)
          clusVolArr << $1
        end
      end
    end
  else
    print_message(INFO, "File #{@opt['f']}/_ADMIN/Novell/Cluster/PoolConfig.xml does not exist. No cluster resources attached")
  end
#Unmount only if the mount was succesful
  if File.exist?("#{@opt['f']}/_ADMIN/Novell")
      ncl_umount(@opt['s'],@opt['f'])
  end
  return clusVolArr 
end

def getVolumesAndMountPoints 
  isSrcLinux = true
  volList = []
  ENV["USER_PASSWORD_REMOTE"] = @opt['p']
  if isSrcLinux
    useSecure = true
    useSecure = false if @opt['source-unsecure-ldap']
    # Get the source server name which, we can pass it to ldap command
    source_server_name = server_name(@opt['s'])
    if source_server_name == nil
      print_message(FATAL, "Unable to get the server name. Ensure eDir is running.")
      exit 1
    end
    context = server_context(@opt['s'])
    if context == nil
        print_message(FATAL, "Unable to get source server context. Ensure eDirctory is running.")
        exit 1
    end
    searchString = source_server_name + "_" + "*"
    #The source server can be a dsfw server, then in that case we have to use dsfw port
    #Fix for BugZilla#742453
    dsfwresult = ""
    #/opt/novell/eDirectory/bin/ldapsearch -x -h 164.99.101.82 -s base -b "" | grep 2.16.840.1.113719.1.513.7.1
    #dsfwcmd = "/opt/novell/eDirectory/bin/ldapsearch -x -h #{@opt['s']} -s base -b \"\" | grep 2.16.840.1.113719.1.513.7.1"
    dsfwcmd = "/usr/bin/ldapsearch -x -h #{@opt['s']} -s base -b \"\" | grep 2.16.840.1.113719.1.513.7.1"
    print_message(INFO, "ldapsearch command executed as #{dsfwcmd}")
    dsfwresult = `#{dsfwcmd}`
    #If the source is NW or non-DSfW OES server, return value will be non-zero
    if $? != 0
        print_message(INFO, "ldapsearch has not identified #{@opt['s']} as DSfW server.")
    end
    if not dsfwresult.nil? and not dsfwresult.empty? and dsfwresult.include?("supportedCapabilities: 2.16.840.1.113719.1.513.7.1")
        port = "1636"
    else
        port = @opt['source-ldap-port']
    end

    #Now get host string
    host = getHostString(@opt['s'], useSecure, port)

    print_message(INFO, "ldapsearch command executed as \"ldapsearch -LLL -s sub -H #{host} -x -D \"#{@opt['a']}\" \"(&(#{searchString})(objectClass=Volume))\" linuxNCPMountPoint -W\"")
    cmd = "ldapsearch -LLL -s sub -H #{host} -x -D \"#{@opt['a']}\" \"(&(#{searchString})(|(objectClass=Volume)(objectClass=ndsVolume)))\" linuxNCPMountPoint -W"
    options = {}
    options[:password] = @opt['p']
    result = executeLdapCmd(cmd, options)
    i = 0
    volume = type = mountPt = ""
    while i < result.length
      attrib = result[i]
      encoded = false
      if attrib.include?("::")
        a, v = attrib.split("::", 2)
        encoded = true
      else
        a, v = attrib.split(":",2)
      end
      v.strip!
      j = i + 1
      while (result[j] != nil and result[j].index(":") == nil)
        v << result[j][1, result[j].length].rstrip
        i = i + 1
        j = j + 1
      end
      if encoded
        val = Base64.decode64(v)
      else
        val = v
      end
      if a == "linuxNCPMountPoint"
        #This is a linuxNCPMountPoint
      elsif result[i+1].include?("linuxNCPMountPoint")
        volume = val[source_server_name.length+1..val.index(",")-1]
        volList << volume
      end
      i = i + 1
    end if result != nil
    return volList
  end
end

# This method will retrieve the list of volumes from the source server 
# and mounts the volumes at the specified location
def mountAllVolumes
  volumes = []
  if @opt['t'].include?("NW")
    ENV['OES_DATA'] = ENV['MNT_PASS']
    cmd = "LC_ALL=en_US.UTF-8 /opt/novell/ncpserv/sbin/ncpshell --volumes --ip=#{@opt['s']} --u=\"#{@adminName}\""
    print_message(INFO, "ncpshell command executed as: #{cmd}")
    volumes = `#{cmd}`
    volumes = volumes.lines.to_a
    if $? != 0
      print_message(FATAL, "Failed to execute ncpshell to list the volumes for server #{@opt['s']} ")
      print_message(FATAL, "Command output: #{volumes} ")
      exit 1
    end

    # We will perform the following:
    # 1. Get List of cluster volumes active on the node
    # 2. Get the diff of all vols and cluster vols to mount
    clusVolArr = getClusterVolumeListOnNetWare volumes

    @totVols = volumes.size
    # volumes contains /n NCP Mounted Volumes/n at the end. So we can skip this. To do this 
    # we need to substract 2 from total size
    @totVols = @totVols - 2
    @totVols = @totVols - clusVolArr.length if not clusVolArr.empty?
    volumes.each do |vol|
      vol.strip!
      #Note: ncpshell returns the lists of volumes in the following format
      #     [VOL_ID] VOLUMENAME
      # The following code parses the list of volumes and gets the volume name
      if vol != nil and vol.length > 0
        volid,volname = vol.split(" ")
        if volid.include?("[") and volname != nil
          volname.strip!
          if volname != ""
            if clusVolArr.length > 0 and clusVolArr.include?(volname)
              print_message(INFO, "Not mounting..  #{volname}")
              next
            end
            begin
              print_message(INFO, "Mounting Volume = #{volname}\n")
              retVal = mig_mount_volume @opt['s'], @adminName,@opt['p'],volname
              if retVal != 0
                @failMounts = @failMounts + 1
              end 
            rescue 
	      unmount_all_volumes
              raise  
            end
          end
        end
      end
    end#end volumes.each 
  else
  #Get non cluster volumes from the node ip address and mount
   volumes = getVolumesAndMountPoints
   @totVols = volumes.length
   volumes.each do |volname|
      begin
        print_message(INFO, "Mounting Volume = #{volname}\n")
        retVal = mig_mount_volume @opt['s'], @adminName,@opt['p'],volname
        if retVal != 0
          @failMounts = @failMounts + 1
        end
        rescue 
	      unmount_all_volumes
        raise
      end
    end
  end
end

def getServerCodePage
  ENV['OES_DATA'] = ENV['MNT_PASS']

  #Step1: Get config.txt from source server
  cmd = "LC_ALL=en_US.UTF-8 /opt/novell/ncpserv/sbin/ncpshell --ip=#{@opt['s']} --u=\"#{@adminName}\" --get --src=\"SYS:SYSTEM/CONFIG.TXT\" --dst=\"#{@opt['f']}/config.txt\""
  print_message(DEBUG, "ncpshell command executed as: #{cmd}\n")
  result = `#{cmd}`
  if $? != 0 or !File.exist?("#{@opt['f']}/config.txt")
    # config.txt does not exist on source. Load config.nlm to generate config.txt
    # Step 2: - Run config NLM on the source server
    cmd = "LC_ALL=en_US.UTF-8 /opt/novell/ncpserv/sbin/ncpshell --ip=#{@opt['s']} --u=\"#{@adminName}\" --invoke --parm1=\"config.nlm\""
    print_message(DEBUG, "ncpshell command to load config.nlm: #{cmd} \n")
    result = `#{cmd}`
    if $? != 0 or result != ""
      print_message(FATAL, "Failed to execute command #{cmd} with error #{result}\n")
      return nil
    end

    sleep 5
    #Step 3: Get config.txt from source server
    cmd = "LC_ALL=en_US.UTF-8 /opt/novell/ncpserv/sbin/ncpshell --ip=#{@opt['s']} --u=\"#{@adminName}\" --get --src=\"SYS:SYSTEM/CONFIG.TXT\" --dst=\"#{@opt['f']}/config.txt\""
    print_message(DEBUG, "ncpshell command executed as: #{cmd}\n")
    result = `#{cmd}`
    if $? != 0 or !File.exist?("#{@opt['f']}/config.txt")
      print_message(FATAL, "getServerCodePage:Failed to execute command #{cmd} with error #{result}\n")
      return nil
    end

  end
  #Step 4: search config.txt for Server DOS Code Page
  cmd = "grep \"Server DOS Code Page\" \"#{@opt['f']}/config.txt\""
  print_message(DEBUG, "Executing command: #{cmd}\n")
  result = `#{cmd}`
  if $? != 0
    print_message(FATAL, "getServerCodePage:Failed to execute command #{cmd} with error #{result}\n")
    return nil
  end
  if result != nil and result.length >0
    tokens = result.split(":")
    if tokens != nil and tokens.size == 2
      codese = tokens[1].strip
      codese.chomp!
# Extract only the digits from the string
      if codese =~ /(\d+)/
        codese = $1
      end
      return codese
    end
  end
return nil
end

# lists all cluster volumes if exists in the given resource
def listclustervols
ENV['USER_PASSWORD_REMOTE'] = ENV['MNT_PASS']
cmd = "LC_ALL=en_US.UTF-8 /opt/novell/sms/bin/smstool --list-cluster-volumes -R #{@opt['s']} -U \"#{@adminName}\""
  print_message(DEBUG, "smstool command executed as: #{cmd}")
  volumes1 = `#{cmd}`
  volumes  = volumes1.split("\n")
  if $? != 0
    print_message(FATAL, "smstool failed to list cluster volumes on #{@opt['s']} retval = #{$?} volumes = #{volumes}")
    exit 1
  end
  volumes.each do |vol|
    puts vol.strip
  end
end

# mounts cluster volumes if exists at the specified path
def mountClusterVolumes
ENV['USER_PASSWORD_REMOTE'] = ENV['MNT_PASS']
cmd = "LC_ALL=en_US.UTF-8 /opt/novell/sms/bin/smstool --list-cluster-volumes -R #{@opt['s']} -U \"#{@adminName}\""
  print_message(INFO, "smstool command executed as: #{cmd}")
  volumes = []

  volumes1 = `#{cmd}`
  volumes = volumes1.split("\n")
  if $? != 0
    print_message(FATAL, "smstool failed to list cluster volumes on #{@opt['s']}")
    exit 1
  end
  @totVols = volumes.length
  volumes.each do |vol|
    #If standard output has SMDR debugging statements then dont process it
    #This fix is provided for bug #792894
    if vol.include? "SMDR Debug Log" or vol.include? "SMDR:###SMSDEBUG###"
	next
    end
    vol.strip!
    # Note: smstool --list-cluster-volumes returns the lists of volumes in the following format
    #  VOLUMENAME: path
    # The following code parses the list of volumes and gets the volume name
    # If cluster is attached to NW node, the first string starts with 'Full Pool', so we need to skip this string
    if vol != nil and vol.length > 0 and vol != "Full Pool"
      volname,path = vol.split(":") 
      # TODO: As of now we don't need path, so we are not going to parse
      volname.strip!
      if volname != "" 
        print_message(INFO, "Mounting Volume = #{volname}\n")
        begin
          retVal = mig_mount_volume @opt['s'], @adminName, @opt['p'], volname
          if retVal != 0
            @failMounts = @failMounts + 1
          end 
        rescue 
          unmount_all_volumes
          raise
        end #begin
      end #if volname != ""      
    end #if vol != nil
  end #volumes.each
end

def getadminName nameInFdn
  adminName = ""
  splitInfo = nameInFdn.split(",") if nameInFdn.include?(",") and nameInFdn.include?("=")
  if splitInfo != nil and splitInfo != "" and splitInfo.length != 0
    splitInfo.each do |singleName|
      name = singleName.split("=")
      if name != nil and name !="" and name.length != 0
        adminName += name[1] + "."
      else
        print_message(FATAL, "Specified admin name #{nameInFdn} is not in correct form")
        exit 1
      end
    end
  else
    print_message(FATAL, "Specified admin name #{nameInFdn} is not in correct form")
    exit 1
  end
  return adminName
end

def main
 $argdef = [
    ['a', 'adminFDN', "The administrator's FDN specified in LDAP format", ParseArgText, false],
    ['p', 'pwd', "The administrator's password", ParseArgText,false],
    ['s', 'source', "Source server IP Address", ParseArgText,false],
    ['f', 'path', "Path to source server volumes", ParseArgText, false],
    ['m',nil,"Specify to mount the volumes",ParseArgBool, false],
    ['u',nil,"Specify to unmount the volumes",ParseArgBool, false],
    [nil, 'debug', "Enable dubug", ParseArgBool, false],
    ['l', 'list-cluster-volumes', "Get the list of cluster volumes for the resource", ParseArgBool, false],
    ['v', 'mount-cluster-volumes', "Mounts only the cluster volumes if exists", ParseArgBool, false],
    ['t', 'source-type', "Source server type NW65, OES1 and OES2", ParseArgText, false],
    [nil, 'source-unsecure-ldap', "use unsecure LDAP for all LDAP commands", ParseArgBool],
    [nil, 'source-ldap-port', "port where LDAP server is listening", ParseArgText],
    ParseArgHelp,
    ParseArgUsage
  ]
  $codeset = nil
  volguidCommand = "#{$0}"  # name of the script.
  debugOpt = false
 $*.each do |arg|
   if arg.strip == "--debug"
      debugOpt = true
   end
   volguidCommand += " #{arg}" # Form the actual command executed.
 end
  initLog(debugOpt, "volmount")
  print_message(DEBUG, "volmount command started at #{`date +%d-%m-%y\\ %H:%M:%S`}")
  print_message(DEBUG, "volmount command executed as: #{volguidCommand}") 
  
  (@opt, extraargs) = parseargs(ARGV, $argdef)
  # Validate arguments
  if @opt['m'] == nil and @opt['v'] == nil and @opt['u'] == nil and @opt['g'] == nil and @opt['l'] == nil
    print_message(FATAL, "Invalid Arguments: either mount or unmount or list option needs to be specified")
    exit 1
  end

  if @opt['a']
    @adminName = getadminName(@opt['a'])
    #credentialDetails['source-username'] = Migration::KeyStore.credential(@opt['s'], :nds_dn, false)[:username]
    if @adminName == nil or @adminName == ""
      print_message(FATAL, "Failed to convert FDN name to eDir name")
      exit 1
    end
    @adminName.chomp!(".")
    print_message(DEBUG, "adminName = #{@adminName}")
  end

  @totVols = 0
  @failMounts = 0
  if @opt['m'] or @opt['g'] or @opt['v']
    if @opt['l']
      print_message(ERROR, "Invalid Arguments: list option cannot be specified with mount or unmount or code page.\n")
      exit 1
    end
    if @opt['l']
      print_message(ERROR, "Invalid Arguments: list option cannot be specified with mount or unmount or code page.\n")
      exit 1
    end
    if @opt['u']
      print_message(ERROR, "Invalid Arguments: unmount option cannot be specified with mount or code page.\n")
      exit 1
    end
    if @opt['f'] == nil
      print_message(ERROR, "Invalid Arguments: mount path should be specified with mount.\n")
      exit 1
    end
    if !File.exist?(@opt['f'])
      print_message(ERROR, "Invalid Path: Specified path does not exist\n")
      exit 1
    end
    if @opt['p']
      ENV['MNT_PASS'] = @opt['p']
    end
    if ENV['MNT_PASS'] == nil
      print_message(ERROR, "Invalid Arguments: Password is not specified\n")
      exit 1
    end
=begin
    @adminName = getadminName(@opt['a'])
    #credentialDetails['source-username'] = Migration::KeyStore.credential(@opt['s'], :nds_dn, false)[:username]
    if @adminName == nil or @adminName == ""
      print_message(FATAL, "Failed to convert FDN name to eDir name")
      exit 1
    end
    @adminName.chomp!(".")
    print_message(DEBUG, "adminName = #{@adminName}")
=end
    @opt['p'] = ENV['MNT_PASS']
    #Get the source server code page

    #Get the lst of volumes and mount them in the specified path
    if @opt['v']
        mountClusterVolumes
    else
        mountAllVolumes
    end
    if (@totVols != 0) and (@totVols == @failMounts)
      print_message(FATAL, "Failed to map all the volumes of source server #{@opt['s']}")
      exit 1
    end
  end
  if @opt['u']
    unmount_all_volumes
  end
  if @opt['l']
    if @opt['s'] == nil or @opt['a'] == nil
      print_message(ERROR, "Invalid Arguments: missing required list options 's' or 'a'.\n")
      exit 1
    end
    if @opt['v']
      print_message(ERROR, "Invalid Arguments: mount cluster volumes cannot be specified with list cluster volumes.\n")
      exit 1
    end
    if @opt['p']
      ENV['MNT_PASS'] = @opt['p']
    end
    if ENV['MNT_PASS'] == nil
      print_message(ERROR, "Invalid Arguments: Password is not specified\n")
      exit 1
    end
    @opt['p'] = ENV['MNT_PASS']
    listclustervols 
  end
  if @failMounts != 0
    print_message(ERROR, "Failed to mount #{@failMounts} volumes")
    exit 2
  end
end

begin 
main
rescue SystemCallError => failed  
  print_message(FATAL, "SystemCallError, #{failed.message}")
  exit failed.errno
rescue MigrationException => e 
  print_message(FATAL, "MigrationException, " + e.to_s)
  exit e.code 
rescue MigSyntaxError => e
  print_message(FATAL, "MigSyntaxError, " + e.to_s)
  printUsage($argdef)
  exit e.code
rescue Interrupt
  print_message(DEBUG, "Interrupted by user")
  exit 0
rescue 
  print_message(FATAL, "Caught exception: #{$!.message}\n Backtrace:\n #{$!.backtrace.join("\n")}")
  exit 1
end
